# datanodeclient
The OpenAPI specification implemented by NLP Sandbox Data Nodes.
# Overview
A NLP Sandbox Data Node is a repository of clinical notes that implements this OpenAPI specification so that other services in the NLP Sandbox ecosystem can access them. For example, a client requests data from a Data Node before passing them as input to an NLP Tool like a Date Annotator, Person Name Annotator, etc.
For the sake of benchmarking NLP Tool, a Data Node can also give access to the gold standard that the NLP Tool is expected to infer (e.g. annotations).


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.2.2
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://nlpsandbox.github.io/nlpsandbox-schemas](https://nlpsandbox.github.io/nlpsandbox-schemas)


## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import datanodeclient
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import datanodeclient
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import datanodeclient
from datanodeclient.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://example.com/api/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = datanodeclient.Configuration(
    host = "http://example.com/api/v1"
)



# Enter a context with an instance of the API client
with datanodeclient.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = datanodeclient.AnnotationApi(api_client)
    dataset_id = 'dataset_id_example' # str | The ID of the dataset
annotation_store_id = 'annotation_store_id_example' # str | The ID of the annotation store
annotation = datanodeclient.Annotation() # Annotation |  (optional)

    try:
        # Create an annotation
        api_response = api_instance.create_annotation(dataset_id, annotation_store_id, annotation=annotation)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AnnotationApi->create_annotation: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://example.com/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AnnotationApi* | [**create_annotation**](docs/AnnotationApi.md#create_annotation) | **POST** /datasets/{datasetId}/annotationStores/{annotationStoreId}/annotations | Create an annotation
*AnnotationApi* | [**delete_annotation**](docs/AnnotationApi.md#delete_annotation) | **DELETE** /datasets/{datasetId}/annotationStores/{annotationStoreId}/annotations/{annotationId} | Delete an annotation
*AnnotationApi* | [**get_annotation**](docs/AnnotationApi.md#get_annotation) | **GET** /datasets/{datasetId}/annotationStores/{annotationStoreId}/annotations/{annotationId} | Get an annotation
*AnnotationApi* | [**list_annotations**](docs/AnnotationApi.md#list_annotations) | **GET** /datasets/{datasetId}/annotationStores/{annotationStoreId}/annotations | List the annotations in an annotation store
*AnnotationStoreApi* | [**create_annotation_store**](docs/AnnotationStoreApi.md#create_annotation_store) | **POST** /datasets/{datasetId}/annotationStores | Create an annotation store
*AnnotationStoreApi* | [**delete_annotation_store**](docs/AnnotationStoreApi.md#delete_annotation_store) | **DELETE** /datasets/{datasetId}/annotationStores/{annotationStoreId} | Delete an annotation store
*AnnotationStoreApi* | [**get_annotation_store**](docs/AnnotationStoreApi.md#get_annotation_store) | **GET** /datasets/{datasetId}/annotationStores/{annotationStoreId} | Get an annotation store
*AnnotationStoreApi* | [**list_annotation_stores**](docs/AnnotationStoreApi.md#list_annotation_stores) | **GET** /datasets/{datasetId}/annotationStores | List the annotation stores in a dataset
*DatasetApi* | [**create_dataset**](docs/DatasetApi.md#create_dataset) | **POST** /datasets | Create a dataset
*DatasetApi* | [**delete_dataset**](docs/DatasetApi.md#delete_dataset) | **DELETE** /datasets/{datasetId} | Delete a dataset by ID
*DatasetApi* | [**get_dataset**](docs/DatasetApi.md#get_dataset) | **GET** /datasets/{datasetId} | Get a dataset by ID
*DatasetApi* | [**list_datasets**](docs/DatasetApi.md#list_datasets) | **GET** /datasets | Get all datasets
*FhirStoreApi* | [**create_fhir_store**](docs/FhirStoreApi.md#create_fhir_store) | **POST** /datasets/{datasetId}/fhirStores | Create a FHIR store
*FhirStoreApi* | [**delete_fhir_store**](docs/FhirStoreApi.md#delete_fhir_store) | **DELETE** /datasets/{datasetId}/fhirStores/{fhirStoreId} | Delete a FHIR store
*FhirStoreApi* | [**get_fhir_store**](docs/FhirStoreApi.md#get_fhir_store) | **GET** /datasets/{datasetId}/fhirStores/{fhirStoreId} | Get a FHIR store
*FhirStoreApi* | [**list_fhir_stores**](docs/FhirStoreApi.md#list_fhir_stores) | **GET** /datasets/{datasetId}/fhirStores | List the FHIR stores in a dataset
*NoteApi* | [**create_note**](docs/NoteApi.md#create_note) | **POST** /datasets/{datasetId}/fhirStores/{fhirStoreId}/fhir/Note | Create a note
*NoteApi* | [**delete_note**](docs/NoteApi.md#delete_note) | **DELETE** /datasets/{datasetId}/fhirStores/{fhirStoreId}/fhir/Note/{noteId} | Delete a note
*NoteApi* | [**get_note**](docs/NoteApi.md#get_note) | **GET** /datasets/{datasetId}/fhirStores/{fhirStoreId}/fhir/Note/{noteId} | Get a note
*NoteApi* | [**list_notes**](docs/NoteApi.md#list_notes) | **GET** /datasets/{datasetId}/fhirStores/{fhirStoreId}/fhir/Note | List notes
*PatientApi* | [**create_patient**](docs/PatientApi.md#create_patient) | **POST** /datasets/{datasetId}/fhirStores/{fhirStoreId}/fhir/Patient | Create a FHIR Patient
*PatientApi* | [**delete_patient**](docs/PatientApi.md#delete_patient) | **DELETE** /datasets/{datasetId}/fhirStores/{fhirStoreId}/fhir/Patient/{patientId} | Delete a FHIR Patient
*PatientApi* | [**get_patient**](docs/PatientApi.md#get_patient) | **GET** /datasets/{datasetId}/fhirStores/{fhirStoreId}/fhir/Patient/{patientId} | Get a FHIR Patient
*PatientApi* | [**list_patients**](docs/PatientApi.md#list_patients) | **GET** /datasets/{datasetId}/fhirStores/{fhirStoreId}/fhir/Patient | List the Patients in a FHIR store
*ServiceApi* | [**service**](docs/ServiceApi.md#service) | **GET** /service | Get service information


## Documentation For Models

 - [Annotation](docs/Annotation.md)
 - [AnnotationSource](docs/AnnotationSource.md)
 - [AnnotationStore](docs/AnnotationStore.md)
 - [Dataset](docs/Dataset.md)
 - [Error](docs/Error.md)
 - [FhirStore](docs/FhirStore.md)
 - [Note](docs/Note.md)
 - [PageOfAnnotationStores](docs/PageOfAnnotationStores.md)
 - [PageOfAnnotationStoresAllOf](docs/PageOfAnnotationStoresAllOf.md)
 - [PageOfAnnotations](docs/PageOfAnnotations.md)
 - [PageOfAnnotationsAllOf](docs/PageOfAnnotationsAllOf.md)
 - [PageOfDatasets](docs/PageOfDatasets.md)
 - [PageOfDatasetsAllOf](docs/PageOfDatasetsAllOf.md)
 - [PageOfFhirStores](docs/PageOfFhirStores.md)
 - [PageOfFhirStoresAllOf](docs/PageOfFhirStoresAllOf.md)
 - [PageOfNotes](docs/PageOfNotes.md)
 - [PageOfNotesAllOf](docs/PageOfNotesAllOf.md)
 - [PageOfPatients](docs/PageOfPatients.md)
 - [PageOfPatientsAllOf](docs/PageOfPatientsAllOf.md)
 - [Patient](docs/Patient.md)
 - [ResourceSource](docs/ResourceSource.md)
 - [ResponsePageMetadata](docs/ResponsePageMetadata.md)
 - [ResponsePageMetadataLinks](docs/ResponsePageMetadataLinks.md)
 - [Service](docs/Service.md)
 - [TextAnnotation](docs/TextAnnotation.md)
 - [TextDateAnnotation](docs/TextDateAnnotation.md)
 - [TextDateAnnotationAllOf](docs/TextDateAnnotationAllOf.md)
 - [TextPersonNameAnnotation](docs/TextPersonNameAnnotation.md)
 - [TextPhysicalAddressAnnotation](docs/TextPhysicalAddressAnnotation.md)
 - [TextPhysicalAddressAnnotationAllOf](docs/TextPhysicalAddressAnnotationAllOf.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

thomas.schaffter@sagebionetworks.org


